TODO
----

* Add appending signature to bookmark and validation signature with GnuPG.
* Add linking social web services with OAuth.
* Add Feed parser and adding new item to bookmark automatically.
* Add job scedular for feed parser and push message to social web services.
* Add applying reST style description.
* Add unit test code.

